==> jc-1.4.0.tar.gz: soot/jimple/parser/lexer/Lexer__24State.h <==
// public class soot.jimple.parser.lexer.Lexer$State

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 25b289a58d5d72bb soot_jimple_parser_lexer_Lexer__24State

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_parser_lexer_Lexer__24State_H_
#define _JC_soot_jimple_parser_lexer_Lexer__24State_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_parser_lexer_Lexer__24State$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_lexer_Lexer__24State$sub_refs	_jc_soot_jimple_parser_lexer_Lexer__24State$sub_refs;
typedef struct _jc_soot_jimple_parser_lexer_Lexer__24State$sub_nonrefs	_jc_soot_jimple_parser_lexer_Lexer__24State$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_lexer_Lexer__24State$refs	_jc_soot_jimple_parser_lexer_Lexer__24State$refs;
typedef struct _jc_soot_jimple_parser_lexer_Lexer__24State$nonrefs	_jc_soot_jimple_parser_lexer_Lexer__24State$nonrefs;
typedef struct _jc_soot_jimple_parser_lexer_Lexer__24State$object	_jc_soot_jimple_parser_lexer_Lexer__24State$object;

typedef struct _jc_soot_jimple_parser_lexer_Lexer__24State$fields_struct	_jc_soot_jimple_parser_lexer_Lexer__24State$fields_struct;
typedef const struct _jc_soot_jimple_parser_lexer_Lexer__24State$vmethods	_jc_soot_jimple_parser_lexer_Lexer__24State$vmethods;
typedef const struct _jc_soot_jimple_parser_lexer_Lexer__24State$vtable	_jc_soot_jimple_parser_lexer_Lexer__24State$vtable;
typedef const struct _jc_soot_jimple_parser_lexer_Lexer__24State$vtype	_jc_soot_jimple_parser_lexer_Lexer__24State$vtype;

// Class fields structure
struct _jc_soot_jimple_parser_lexer_Lexer__24State$fields_struct {
	struct _jc_soot_jimple_parser_lexer_Lexer__24State$object	*INITIAL;
};
extern _jc_soot_jimple_parser_lexer_Lexer__24State$fields_struct _jc_soot_jimple_parser_lexer_Lexer__24State$class_fields;

// Constructors
extern void _jc_soot_jimple_parser_lexer_Lexer__24State$method$_init$7f1776288300b98d(_jc_env *, struct _jc_soot_jimple_parser_lexer_Lexer__24State$object *, jint);

// Virtual methods
extern jint _jc_soot_jimple_parser_lexer_Lexer__24State$method$id$a415277685672631(_jc_env *, struct _jc_soot_jimple_parser_lexer_Lexer__24State$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_lexer_Lexer__24State$method_info$id$a415277685672631;

// Static methods
extern void _jc_soot_jimple_parser_lexer_Lexer__24State$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_parser_lexer_Lexer__24State$vmethods {
	jint	(*id$a415277685672631)(_jc_env *, struct _jc_soot_jimple_parser_lexer_Lexer__24State$object *);
};

// Vtable
struct _jc_soot_jimple_parser_lexer_Lexer__24State$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_lexer_Lexer__24State$vmethods	soot_jimple_parser_lexer_Lexer__24State;
};

// Vtype
struct _jc_soot_jimple_parser_lexer_Lexer__24State$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_lexer_Lexer__24State$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_lexer_Lexer__24State$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_lexer_Lexer__24State$refs {
    _jc_soot_jimple_parser_lexer_Lexer__24State$sub_refs	soot_jimple_parser_lexer_Lexer__24State;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_lexer_Lexer__24State$sub_nonrefs {
	jint	id;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_lexer_Lexer__24State$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_lexer_Lexer__24State$sub_nonrefs	soot_jimple_parser_lexer_Lexer__24State;
};

// Object instance structure
struct _jc_soot_jimple_parser_lexer_Lexer__24State$object {
	_jc_soot_jimple_parser_lexer_Lexer__24State$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_lexer_Lexer__24State$vtype	*vtype;
	_jc_soot_jimple_parser_lexer_Lexer__24State$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_lexer_Lexer__24State$vtype _jc_soot_jimple_parser_lexer_Lexer__24State$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_lexer_Lexer__24State, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_lexer_Lexer__24State$class_object;

#endif	/* _JC_soot_jimple_parser_lexer_Lexer__24State_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/lexer/Lexer__24State.h <==
// public class soot.jimple.parser.lexer.Lexer$State

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 25b289a58d5d72bb soot_jimple_parser_lexer_Lexer__24State

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_parser_lexer_Lexer__24State_H_
#define _JC_soot_jimple_parser_lexer_Lexer__24State_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_parser_lexer_Lexer__24State$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_lexer_Lexer__24State$sub_refs	_jc_soot_jimple_parser_lexer_Lexer__24State$sub_refs;
typedef struct _jc_soot_jimple_parser_lexer_Lexer__24State$sub_nonrefs	_jc_soot_jimple_parser_lexer_Lexer__24State$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_lexer_Lexer__24State$refs	_jc_soot_jimple_parser_lexer_Lexer__24State$refs;
typedef struct _jc_soot_jimple_parser_lexer_Lexer__24State$nonrefs	_jc_soot_jimple_parser_lexer_Lexer__24State$nonrefs;
typedef struct _jc_soot_jimple_parser_lexer_Lexer__24State$object	_jc_soot_jimple_parser_lexer_Lexer__24State$object;

typedef struct _jc_soot_jimple_parser_lexer_Lexer__24State$fields_struct	_jc_soot_jimple_parser_lexer_Lexer__24State$fields_struct;
typedef const struct _jc_soot_jimple_parser_lexer_Lexer__24State$vmethods	_jc_soot_jimple_parser_lexer_Lexer__24State$vmethods;
typedef const struct _jc_soot_jimple_parser_lexer_Lexer__24State$vtable	_jc_soot_jimple_parser_lexer_Lexer__24State$vtable;
typedef const struct _jc_soot_jimple_parser_lexer_Lexer__24State$vtype	_jc_soot_jimple_parser_lexer_Lexer__24State$vtype;

// Class fields structure
struct _jc_soot_jimple_parser_lexer_Lexer__24State$fields_struct {
	struct _jc_soot_jimple_parser_lexer_Lexer__24State$object	*INITIAL;
};
extern _jc_soot_jimple_parser_lexer_Lexer__24State$fields_struct _jc_soot_jimple_parser_lexer_Lexer__24State$class_fields;

// Constructors
extern void _jc_soot_jimple_parser_lexer_Lexer__24State$method$_init$7f1776288300b98d(_jc_env *, struct _jc_soot_jimple_parser_lexer_Lexer__24State$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_jimple_parser_lexer_Lexer__24State$method$id$a415277685672631(_jc_env *, struct _jc_soot_jimple_parser_lexer_Lexer__24State$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_lexer_Lexer__24State$method_info$id$a415277685672631;

// Static methods
extern void _jc_soot_jimple_parser_lexer_Lexer__24State$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_parser_lexer_Lexer__24State$vmethods {
	jint	(*id$a415277685672631)(_jc_env *, struct _jc_soot_jimple_parser_lexer_Lexer__24State$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_lexer_Lexer__24State$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_lexer_Lexer__24State$vmethods	soot_jimple_parser_lexer_Lexer__24State;
};

// Vtype
struct _jc_soot_jimple_parser_lexer_Lexer__24State$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_lexer_Lexer__24State$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_lexer_Lexer__24State$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_lexer_Lexer__24State$refs {
    _jc_soot_jimple_parser_lexer_Lexer__24State$sub_refs	soot_jimple_parser_lexer_Lexer__24State;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_lexer_Lexer__24State$sub_nonrefs {
	jint	id;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_lexer_Lexer__24State$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_lexer_Lexer__24State$sub_nonrefs	soot_jimple_parser_lexer_Lexer__24State;
};

// Object instance structure
struct _jc_soot_jimple_parser_lexer_Lexer__24State$object {
	_jc_soot_jimple_parser_lexer_Lexer__24State$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_lexer_Lexer__24State$vtype	*vtype;
	_jc_soot_jimple_parser_lexer_Lexer__24State$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_lexer_Lexer__24State$vtype _jc_soot_jimple_parser_lexer_Lexer__24State$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_lexer_Lexer__24State, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_lexer_Lexer__24State$class_object;

#endif	/* _JC_soot_jimple_parser_lexer_Lexer__24State_H_ */
